#relationList {
    overflow-y: auto;
    max-height: 40vh;
}

#relationdialog {
    border: 1px solid black;
    border-radius: .3rem;
    overflow: visible;
    padding: 0;
    opacity: 1;
    transform: scale(1);
    transition: all 0.5s ease-in-out;

    @starting-style {
        opacity: 0;
        transform: scale(0.8);
    }
}

#relation-dialog-content {
    padding: 1rem;
    overflow-y: auto;
    max-height: 80vh;
}
