# Generated by Django 5.1.7 on 2025-04-16 09:25

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("collections", "0003_skoscollection_unique_name_parent_and_more"),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name="skoscollection",
            name="check_name_pipe",
        ),
        migrations.RemoveField(
            model_name="skoscollection",
            name="parent",
        ),
    ]
