{% load i18n %}

{% block action-nav %}
  {% if object.get_delete_permission in perms or object_create_perm in perms %}
    <ul class="nav nav-tabs card-header-tabs float-end">
      <li class="nav-item">
        <a class="nav-link dropdown-toggle" data-bs-toggle="dropdown" href="#">{% translate "Actions" %}</a>
        <div class="dropdown-menu">
          {% if object.get_delete_permission in perms %}
            <a class="dropdown-item object-delete"
               href="{{ object.get_delete_url }}">
              <span class="material-symbols-outlined material-symbols-align">delete</span>{% translate "Delete" %}
            </a>
          {% endif %}
          {% if object.get_add_permission in perms %}
            <a class="object-duplicate dropdown-item"
               href="{{ object.get_duplicate_url }}">
              <span class="material-symbols-outlined material-symbols-align">content_copy</span>{% translate "Duplicate" %}
            </a>
            <a class="object-merge dropdown-item"
               href="{{ object.get_select_merge_or_enrich_url }}">
              <span class="material-symbols-outlined material-symbols-align">cell_merge</span>{% translate "Merge" %}
            </a>
          {% endif %}
        </div>
      </li>
    </ul>
  {% endif %}
{% endblock action-nav %}
