summary.more-less-column {
    list-style: none;
    appearance: none;
    /* for WebKit browsers */
    -webkit-appearance: none;
}

/* optional: remove ::marker for older browsers */
summary.more-less-column ::marker {
    content: none;
}

summary.more-less-column {
    cursor: pointer;
}

/* add "Show more" text when collapsed */
summary.more-less-column::after {
    content: " Show more";
    font-weight: normal;
    font-size: smaller;
    color: grey;
}

/* hide the summary text when expanded, show only "Show less" */
details[open] summary.more-less-column::before {
    content: "Show less";
    color: grey;
}

/* hide the original summary text when expanded */
details[open] summary.more-less-column::after {
    content: "";
}

details[open] summary.more-less-column {
    visibility: hidden;
}

/* make sure the generated "Show less" text is visible */
details[open] summary.more-less-column::before {
    visibility: visible;
}
