{% extends basetemplate|default:"base.html" %}
{% load generic %}
{% load crispy_forms_tags %}
{% load i18n %}

{% block title %}
  {% blocktranslate %}Updating {{ object }}{% endblocktranslate %}
{% endblock title %}

{% block content %}
  <div class="container">
    {% if form.fields %}
      <h4 class="mb-4">
        {% blocktranslate with url=object.get_absolute_url %}Updating <a href="{{ url }}">{{ object }}</a> using the data from <a href="{{ uri }}">{{ uri }}</a>{% endblocktranslate %}
      </h4>
      {% crispy form form.helper %}
    {% endif %}
  </div>
{% endblock content %}
