@font-face {
    font-family: 'Material Symbols Outlined';
    font-style: normal;
    src: url(/static/fonts/material-symbols.woff) format('woff');
}

.material-symbols-outlined {
    font-family: 'Material Symbols Outlined';
    font-weight: normal;
    font-style: normal;
    /* preferred icon size */
    font-size: 24px;
    display: inline-block;
    line-height: 1;
    text-transform: none;
    letter-spacing: normal;
    word-wrap: normal;
    white-space: nowrap;
    direction: ltr;
}

/* fix misaligned Material Icons/Symbols */
.material-symbols-align {
    vertical-align: bottom;
}
