/* object actions */
.object-view {
    color: rgb(25, 135, 84) !important;
}

.object-edit {
    color: rgb(255, 193, 7) !important;
}

.object-delete {
    color: rgb(220, 53, 69) !important;
}

.object-duplicate {
    color: blueviolet;
}

.object-merge {
    color: dodgerblue;
}

.object-history {
    color: #007bff;
}
