{% if object.get_listview_url %}
  <a href="{{ object.get_listview_url }}"><small>{{ object.get_verbose_name_plural }}</small></a>
{% else %}
  <small>{{ object.get_verbose_name_plural }}</small>
{% endif %}
