# Generated by Django 5.1 on 2024-09-18 06:35

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("sample_project", "0002_iscousinof_ispartof_issiblingof_livesin"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="versiongroup",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical group",
                "verbose_name_plural": "historical groups",
            },
        ),
        migrations.AlterModelOptions(
            name="versionperson",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical person",
                "verbose_name_plural": "historical persons",
            },
        ),
        migrations.AlterModelOptions(
            name="versionplace",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical place",
                "verbose_name_plural": "historical places",
            },
        ),
    ]
